@@ -39,7 +39,7 @@
     the main thread by manually running them in a worker. This can be done in
     several ways:
 
-    - Directly using the {{!Luv.Thread.Pool} libuv thread pool}.
+    - Directly using the {{!Luv.Thread_pool} libuv thread pool}.
     - By creating a thread manually with {!Luv.Thread.create}.
     - By creating a thread manually with OCaml's standard
       {{:https://caml.inria.fr/pub/docs/manual-ocaml/libref/Thread.html}
@@ -1082,7 +1082,9 @@ sig
       (unit, Error.t) result
   (** Synchronous version of {!Luv.File.lutime}.
 
-      @since Luv 0.5.2 (libuv 1.36.0). *)
+      Requires Luv 0.5.2 and libuv 1.36.0.
+
+      {{!Luv.Require} Feature check}: [Luv.Require.(has fs_lutime)] *)
 
   val link :
     string -> link:string ->
