@@ -5,8 +5,8 @@
 
 type t = {
   username : string;
-  uid : int;
-  gid : int;
+  uid : Unsigned.ulong;
+  gid : Unsigned.ulong;
   shell : string option;
   homedir : string;
 }
